@@ -1,14 +1,9 @@
 """nycdb - nyc housing database"""
 
-__version__ = '0.1.0'
-__author__ = 'ziggy <ziggy@elephant-bird.net>'
 #__all__ = []
 
-from . import typecast, sql, transform, bbl, address, geo
+from . import typecast, sql, transform, bbl, address
 from .database import Database
 from .dataset import Dataset
 from .datasets import datasets
 from .file import File
-
-
-#datasets = _datasets()
